Crate yolol_number

Crate yolol_number 

Modules

prelude
Import this to get the standard YololNumber typedef and all the traits you need to perform all the operations that you could want.

Enums

FromStrError

Type Aliases

YololNumber
A typedef for a YololNumber backed by the defacto standard: an i128.